@@ -268,13 +268,13 @@ class NVT(lammps_step.NVE):
             text += (
                 "using a canonical sampling thermostat using velocity "
                 "rescaling (CSVR) with a damping time of {Tdamp} and "
-                "a {random_seed}."
+                "a {seed}."
             )
         elif 'csld' in P['thermostat']:
             text += (
                 "using a canonical sampling thermostat using Langevin "
                 "dynamics (CSLD) with a damping time of {Tdamp} and "
-                "a {random_seed}."
+                "a {seed}."
             )
         elif P['thermostat'] == 'velocity rescaling':
             text += (
@@ -290,7 +290,7 @@ class NVT(lammps_step.NVE):
         elif P['thermostat'] == 'Langevin':
             text += (
                 "using a Langevin thermostat with a damping time "
-                "of {Tdamp} and a {random_seed}"
+                "of {Tdamp} and a {seed}"
             )
         else:
             text += ("using the thermostat given by {thermostat}")
@@ -326,22 +326,11 @@ class NVT(lammps_step.NVE):
         )
 
         # Fix variables with special cases
-
-        # These need to be based on masses...
-        if P['timestep'] == 'normal':
-            timestep = 1.0
-            P['timestep'] = Q_(timestep, ureg.fs)
-        elif P['timestep'] == 'accurate but slow':
-            timestep = 0.5
-            P['timestep'] = Q_(timestep, ureg.fs)
-        elif P['timestep'] == 'coarse but fast':
-            timestep = 2.0
-            P['timestep'] = Q_(timestep, ureg.fs)
-        else:
-            timestep = P['timestep'].to('fs').magnitude
+        timestep, P['timestep'] = self.timestep(P['timestep'])
 
         if P['seed'] == 'random':
-            P['seed'] = int(random.random() * 2**31)
+            # Apparently the seed must be no larger than 900,000,000
+            P['seed'] = int(random.random() * 899999999)
 
         # Have to fix formatting for printing...
         PP = dict(P)
@@ -353,12 +342,12 @@ class NVT(lammps_step.NVE):
             __(self.description_text(PP), **PP, indent=3 * ' ').__str__()
         )
 
-        time = P['time'].to('fs').magnitude
+        time = lammps_step.to_lammps_units(P['time'], quantity='time')
         nsteps = round(time / timestep)
 
-        T0 = P['T0'].to('K').magnitude
-        T1 = P['T1'].to('K').magnitude
-        Tdamp = P['Tdamp'].to('fs').magnitude
+        T0 = lammps_step.to_lammps_units(P['T0'], quantity='temperature')
+        T1 = lammps_step.to_lammps_units(P['T1'], quantity='temperature')
+        Tdamp = lammps_step.to_lammps_units(P['Tdamp'], quantity='time')
 
         thermo_properties = (
             'time temp press etotal ke pe ebond '
@@ -415,9 +404,14 @@ class NVT(lammps_step.NVE):
             nfixes += 1
             lines.append('fix                 {} '.format(nfixes) + 'all nve')
         elif P['thermostat'] == 'velocity rescaling':
-            frequency = P['frequency'].to('fs').magnitude
+            frequency = lammps_step.to_lammps_units(
+                P['frequency'], quantity='time'
+            )
+
             nevery = round(nsteps / (frequency / timestep))
-            window = P['window'].to('K').magnitude
+            window = lammps_step.to_lammps_units(
+                P['window'], quantity='temperature'
+            )
             fraction = P['fraction']
             nfixes += 1
             lines.append(
@@ -467,7 +461,9 @@ class NVT(lammps_step.NVE):
                 )
             )
         else:
-            sampling = P['sampling'].to('fs').magnitude
+            sampling = lammps_step.to_lammps_units(
+                P['sampling'], quantity='time'
+            )
             nevery = round(sampling / timestep)
             nfreq = int(nsteps / nevery)
             nrepeat = 1
